@@ -1,10 +1,7 @@
-use lazy_static::lazy_static;
+use crate::settings::SettingsColors;
+use crate::typer::TestColors;
 use tui::style::{Color, Style};
 
-lazy_static! {
-    pub static ref THEME: Theme = Theme::default();
-}
-
 pub trait ToForeground {
     fn fg(self) -> Style;
 }
@@ -16,9 +13,10 @@ impl ToForeground for Color {
 }
 
 #[derive(Debug, Clone, Copy)]
+#[cfg_attr(test, derive(PartialEq))]
 pub struct Theme {
     pub done: Color,
-    pub wrong: Color,
+    pub mistake: Color,
     pub todo: Color,
     pub hover: Color,
     pub active: Color,
@@ -28,10 +26,26 @@ impl Default for Theme {
     fn default() -> Self {
         Theme {
             done: Color::White,
-            wrong: Color::Red,
+            mistake: Color::Red,
             todo: Color::Gray,
             hover: Color::Magenta,
             active: Color::Green,
         }
     }
 }
+
+impl Theme {
+    pub fn to_settings_colors(&self) -> SettingsColors {
+        SettingsColors {
+            hover: self.hover,
+            active: self.active,
+        }
+    }
+    pub fn to_test_colors(&self) -> TestColors {
+        TestColors {
+            todo: self.todo,
+            done: self.done,
+            wrong: self.mistake,
+        }
+    }
+}
