@@ -9,6 +9,12 @@ use tui::style::Color;
 
 pub const SCRIPT_SIGN: &'static str = "#!";
 
+pub static TEST_MODS: phf::Map<&'static str, TestMod> = phf::phf_map! {
+    "punctuation" => TestMod::Punctuation,
+    "numbers" => TestMod::Numbers,
+    "symbols" => TestMod::Symbols,
+};
+
 pub fn is_script(text: &str) -> bool {
     if text.len() < 2 {
         return false;
@@ -31,19 +37,13 @@ pub enum TestVariant {
     Script,
 }
 
-#[derive(Clone, Copy, PartialEq, Eq, Hash)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
 pub enum TestMod {
     Punctuation,
     Numbers,
     Symbols,
 }
 
-pub static TEST_MODS: phf::Map<&'static str, TestMod> = phf::phf_map! {
-    "Punctuation" => TestMod::Punctuation,
-    "Numbers" => TestMod::Numbers,
-    "Symbols" => TestMod::Symbols,
-};
-
 impl fmt::Display for TestMod {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
@@ -54,13 +54,39 @@ impl fmt::Display for TestMod {
     }
 }
 
-#[allow(dead_code)]
+pub struct TestSummary {
+    pub correct_chars: usize,
+    pub mistakes: usize,
+    pub wpm: f64,
+    pub acc: f64,
+}
+
+impl Default for TestSummary {
+    fn default() -> Self {
+        Self {
+            correct_chars: 0,
+            mistakes: 0,
+            wpm: 0.,
+            acc: 0.,
+        }
+    }
+}
+
+/// This stuct contains information about
+/// test type and also the eventual result of a test
+/// these are both dispalyed at the post screen
+/// so it makes sense to have them in one place
+/// but it is kinda messy???
 pub struct TypingTestConfig {
+    // test type
     pub name: String,
     pub variant: TestVariant,
     pub length: usize,
-    pub frequency: usize,
+    pub word_pool: usize,
     pub mods: HashSet<TestMod>,
+
+    // summary
+    pub test_summary: TestSummary,
 }
 
 impl fmt::Display for TypingTestConfig {
@@ -76,8 +102,8 @@ impl fmt::Display for TypingTestConfig {
                 }
                 write!(
                     f,
-                    "{}: {} from {} {}",
-                    self.name, self.length, self.frequency, mods
+                    "{}: {}/{} {}",
+                    self.name, self.length, self.word_pool, mods
                 )
             }
             _ => write!(f, "{}", self.name),
@@ -91,13 +117,41 @@ impl Default for TypingTestConfig {
             name: String::from("english"),
             variant: TestVariant::Standard,
             length: 25,
-            frequency: 5000,
+            word_pool: 5000,
             mods: HashSet::default(),
+            test_summary: TestSummary::default(),
         }
     }
 }
 
 impl TypingTestConfig {
+    /// checks if the file name corresponds to a valid path
+    /// and whether or not the word_pool field
+    /// is in bounds in respect to acutal number of words
+    /// avaible in the file
+    ///
+    /// returns the maximum possible value of word_pool to be cached
+    fn validate(&mut self) -> usize {
+        let path = self.get_file_path();
+        if !path.is_file() {
+            self.name = "english".to_string()
+        }
+
+        let lines = count_lines_from_path(path).expect(" fallback to the english word file ");
+
+        if self.word_pool > lines {
+            self.word_pool = lines;
+        }
+        lines
+    }
+
+    fn get_file_path(&self) -> PathBuf {
+        match self.variant {
+            TestVariant::Standard => self.get_words_file_path(),
+            TestVariant::Script => self.get_scripts_file_path(),
+        }
+    }
+
     pub fn get_words_file_path(&self) -> PathBuf {
         storage::get_word_list_path(&self.name)
     }
@@ -109,9 +163,24 @@ impl TypingTestConfig {
     }
 }
 
+pub struct SettingsColors {
+    pub hover: Color,
+    pub active: Color,
+}
+
+impl Default for SettingsColors {
+    fn default() -> Self {
+        Self {
+            hover: Color::Magenta,
+            active: Color::Green,
+        }
+    }
+}
+
 pub struct Settings {
     pub hovered: SetList,
     pub active: SetList,
+    pub colors: SettingsColors,
 
     pub test_cfg: TypingTestConfig,
 
@@ -126,47 +195,15 @@ impl Default for Settings {
     fn default() -> Self {
         let length_list = StatefulList::with_items(vec_of_strings!["10", "15", "25", "50", "100"]);
 
-        // TODO haphazardly implemented cleanup neeeded :broom:
-        // lets not kid myself everything is
-        // but this especially<question mark>
-        let mut words_list: Vec<String> = storage::get_storage_dir()
-            .join("words")
-            .read_dir()
-            .unwrap()
-            .map(|i| {
-                i.unwrap()
-                    .path()
-                    .iter()
-                    .last()
-                    .unwrap()
-                    .to_string_lossy()
-                    .to_string()
-            })
-            .collect();
-
-        let scripts_iterator = storage::get_storage_dir()
-            .join("scripts")
-            .read_dir()
-            .unwrap()
-            .map(|i| {
-                i.unwrap()
-                    .path()
-                    .iter()
-                    .last()
-                    .unwrap()
-                    .to_string_lossy()
-                    .to_string()
-            })
-            .map(|s| format!("{}{}", SCRIPT_SIGN, s));
-
-        words_list.extend(scripts_iterator);
+        let words_list = storage::parse_storage_contents();
 
         let mod_list: Vec<String> = TEST_MODS.keys().map(|&x| x.to_string()).collect();
 
         let test_cfg = TypingTestConfig::default();
+
         let mut word_amount_cache = HashMap::new();
 
-        let word_count = count_lines_from_path(&test_cfg.get_words_file_path());
+        let word_count = count_lines_from_path(&test_cfg.get_words_file_path()).unwrap();
         word_amount_cache.insert(test_cfg.name.clone(), word_count);
         let frequency_list = create_frequency_list(word_count);
 
@@ -180,22 +217,42 @@ impl Default for Settings {
             test_cfg,
             tests_list: StatefulList::with_items(words_list),
             mods_list: StatefulList::with_items(mod_list),
+            colors: SettingsColors::default(),
         }
     }
 }
 
 impl Settings {
-    // length freq
-    // words mods
+    /// TODO a lot of repetitive code taken from default function
+    /// restructure ?? idk
+    /// I can't do ..Self::default() as that would count lines twice
+    pub fn with_config(colors: SettingsColors, ttc: TypingTestConfig) -> Self {
+        let length_list = StatefulList::with_items(vec_of_strings!["10", "15", "25", "50", "100"]);
+        let words_list = storage::parse_storage_contents();
+        let mod_list: Vec<String> = TEST_MODS.keys().map(|&x| x.to_string()).collect();
 
-    // test length
-    // freq mods
+        let mut word_amount_cache = HashMap::new();
 
-    pub fn color_hover_or_active(
-        &self,
-        hover_color: Color,
-        active_color: Color,
-    ) -> HashMap<SetList, Option<Color>> {
+        let mut test_cfg = ttc;
+        let word_count = test_cfg.validate();
+        word_amount_cache.insert(test_cfg.name.clone(), word_count);
+        let frequency_list = create_frequency_list(word_count);
+
+        Self {
+            hovered: SetList::Length,
+            active: SetList::Nil,
+
+            length_list,
+            frequency_list,
+            word_amount_cache,
+            test_cfg,
+            tests_list: StatefulList::with_items(words_list),
+            mods_list: StatefulList::with_items(mod_list),
+            colors,
+        }
+    }
+
+    pub fn color_hover_or_active(&self) -> HashMap<SetList, Option<Color>> {
         let mut hm: HashMap<SetList, Option<Color>> = HashMap::with_capacity(4);
         hm.insert(SetList::Length, None);
         hm.insert(SetList::Test, None);
@@ -203,11 +260,11 @@ impl Settings {
         hm.insert(SetList::Mods, None);
 
         if self.hovered != SetList::Nil {
-            hm.insert(self.hovered, Some(hover_color));
+            hm.insert(self.hovered, Some(self.colors.hover));
             return hm;
         }
 
-        hm.insert(self.active, Some(active_color));
+        hm.insert(self.active, Some(self.colors.active));
         hm
     }
 
@@ -225,7 +282,7 @@ impl Settings {
         if let Some(word_count) = self.word_amount_cache.get(key) {
             *word_count
         } else {
-            let word_count = count_lines_from_path(storage::get_word_list_path(key));
+            let word_count = count_lines_from_path(storage::get_word_list_path(key)).unwrap();
             self.word_amount_cache.insert(key.to_string(), word_count);
             word_count
         }
@@ -257,8 +314,8 @@ impl Settings {
                     let word_count = self.get_word_count(&chosen_test_name);
 
                     self.frequency_list = create_frequency_list(word_count);
-                    if self.test_cfg.frequency > word_count {
-                        self.test_cfg.frequency = word_count;
+                    if self.test_cfg.word_pool > word_count {
+                        self.test_cfg.word_pool = word_count;
                     }
                 }
 
@@ -266,7 +323,7 @@ impl Settings {
             }
 
             SetList::Frequency => {
-                self.test_cfg.frequency = self
+                self.test_cfg.word_pool = self
                     .frequency_list
                     .get_item()
                     .parse::<usize>()
